function varargout = while_s(varargin)
% WHILE_S M-file for while_s.fig
%      WHILE_S, by itself, creates a new WHILE_S or raises the existing
%      singleton*.
%
%      H = WHILE_S returns the handle to a new WHILE_S or the handle to
%      the existing singleton*.
%
%      WHILE_S('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in WHILE_S.M with the given input arguments.
%
%      WHILE_S('Property','Value',...) creates a new WHILE_S or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before while_s_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to while_s_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help while_s

% Last Modified by GUIDE v2.5 15-Jan-2010 14:26:46


% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @while_s_OpeningFcn, ...
                   'gui_OutputFcn',  @while_s_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before while_s is made visible.
function while_s_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to while_s (see VARARGIN)

% Choose default command line output for while_s
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes while_s wait for user response (see UIRESUME)
% uiwait(handles.figure1);

stop_w=0;
setappdata(0,'stop_w',stop_w);

% --- Outputs from this function are returned to the command line.
function varargout = while_s_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
stop_w=1;

%stop_w=get(handles.pushbutton1,'value');
setappdata(0,'stop_w',stop_w);

close('Quitter');